return <<'END';
00a6	00a7
00a9	
00ae	
00b0	
00b6	
0482	
06e9	
06fd	06fe
09fa	
0b70	
0f01	0f03
0f13	0f17
0f1a	0f1f
0f34	
0f36	
0f38	
0fbe	0fc5
0fc7	0fcc
0fcf	
2100	2101
2103	2106
2108	2109
2114	
2116	2118
211e	2123
2125	
2127	
2129	
212e	
2132	
213a	
2195	2199
219c	219f
21a1	21a2
21a4	21a5
21a7	21ad
21af	21cd
21d0	21d1
21d3	
21d5	21f3
2300	2307
230c	231f
2322	2328
232b	237b
237d	239a
2400	2426
2440	244a
249c	24e9
2500	2595
25a0	25b6
25b8	25c0
25c2	25f7
2600	2613
2619	266e
2670	2671
2701	2704
2706	2709
270c	2727
2729	274b
274d	
274f	2752
2756	
2758	275e
2761	2767
2794	
2798	27af
27b1	27be
2800	28ff
2e80	2e99
2e9b	2ef3
2f00	2fd5
2ff0	2ffb
3004	
3012	3013
3020	
3036	3037
303e	303f
3190	3191
3196	319f
3200	321c
322a	3243
3260	327b
327f	
328a	32b0
32c0	32cb
32d0	32fe
3300	3376
337b	33dd
33e0	33fe
a490	a4a1
a4a4	a4b3
a4b5	a4c0
a4c2	a4c4
a4c6	
ffe4	
ffe8	
ffed	ffee
fffc	fffd
END
